
TODO: TODO_75_52_01_67: `token_bucket`-s to support multiple var args

Because of `envelope_container` limit consumption per FS_97_64_39_94 `token_bucket`,
it is possible to support more than one FS_18_64_57_18 varargs per command line.
How?
Each `envelope_container` feeds on the single `token_bucket` for its args spec to specify search for `data_envelopes`.

TODO: This will require update to logic how to move current `envelope_container`
      to next one based on location of cursor in relation to `token_bucket` delimiters.
